@@ -8,7 +8,7 @@ setupX <- function(fit, f, name, nn, cond, ...) {
   D <- rbind(f[,names(df)], df)
   form <- formula(fit)[3]
   
-  b <- if ("lme" %in% class(fit)) fixed.effects(fit) else coef(fit)
+  b <- if ("lme" %in% class(fit)) nlme::fixed.effects(fit) else coef(fit)
   
   if (class(fit)[1]=="mlm") {
     ind <- apply(is.finite(b), 1, all)
